/****************************************************************************
** Meta object code from reading C++ file 'ksudoku.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/ksudoku-17.08.3/src/gui/ksudoku.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ksudoku.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KSudoku_t {
    QByteArrayData data[39];
    char stringdata0[439];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KSudoku_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KSudoku_t qt_meta_stringdata_KSudoku = {
    {
QT_MOC_LITERAL(0, 0, 7), // "KSudoku"
QT_MOC_LITERAL(1, 8, 15), // "settingsChanged"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 11), // "onCompleted"
QT_MOC_LITERAL(4, 37, 9), // "isCorrect"
QT_MOC_LITERAL(5, 47, 8), // "required"
QT_MOC_LITERAL(6, 56, 8), // "withHelp"
QT_MOC_LITERAL(7, 65, 17), // "showWelcomeScreen"
QT_MOC_LITERAL(8, 83, 9), // "startGame"
QT_MOC_LITERAL(9, 93, 21), // "const::ksudoku::Game&"
QT_MOC_LITERAL(10, 115, 4), // "game"
QT_MOC_LITERAL(11, 120, 14), // "endCurrentGame"
QT_MOC_LITERAL(12, 135, 10), // "queryClose"
QT_MOC_LITERAL(13, 146, 17), // "difficultyChanged"
QT_MOC_LITERAL(14, 164, 30), // "KGameDifficulty::standardLevel"
QT_MOC_LITERAL(15, 195, 10), // "difficulty"
QT_MOC_LITERAL(16, 206, 15), // "symmetryChanged"
QT_MOC_LITERAL(17, 222, 8), // "symmetry"
QT_MOC_LITERAL(18, 231, 7), // "gameNew"
QT_MOC_LITERAL(19, 239, 8), // "gameOpen"
QT_MOC_LITERAL(20, 248, 8), // "gameSave"
QT_MOC_LITERAL(21, 257, 10), // "gameSaveAs"
QT_MOC_LITERAL(22, 268, 9), // "gamePrint"
QT_MOC_LITERAL(23, 278, 10), // "gameExport"
QT_MOC_LITERAL(24, 289, 4), // "undo"
QT_MOC_LITERAL(25, 294, 4), // "redo"
QT_MOC_LITERAL(26, 299, 4), // "push"
QT_MOC_LITERAL(27, 304, 3), // "pop"
QT_MOC_LITERAL(28, 308, 8), // "giveHint"
QT_MOC_LITERAL(29, 317, 9), // "autoSolve"
QT_MOC_LITERAL(30, 327, 9), // "dubPuzzle"
QT_MOC_LITERAL(31, 337, 11), // "genMultiple"
QT_MOC_LITERAL(32, 349, 18), // "optionsPreferences"
QT_MOC_LITERAL(33, 368, 14), // "updateSettings"
QT_MOC_LITERAL(34, 383, 13), // "changeCaption"
QT_MOC_LITERAL(35, 397, 4), // "text"
QT_MOC_LITERAL(36, 402, 10), // "onModified"
QT_MOC_LITERAL(37, 413, 10), // "isModified"
QT_MOC_LITERAL(38, 424, 14) // "enableMessages"

    },
    "KSudoku\0settingsChanged\0\0onCompleted\0"
    "isCorrect\0required\0withHelp\0"
    "showWelcomeScreen\0startGame\0"
    "const::ksudoku::Game&\0game\0endCurrentGame\0"
    "queryClose\0difficultyChanged\0"
    "KGameDifficulty::standardLevel\0"
    "difficulty\0symmetryChanged\0symmetry\0"
    "gameNew\0gameOpen\0gameSave\0gameSaveAs\0"
    "gamePrint\0gameExport\0undo\0redo\0push\0"
    "pop\0giveHint\0autoSolve\0dubPuzzle\0"
    "genMultiple\0optionsPreferences\0"
    "updateSettings\0changeCaption\0text\0"
    "onModified\0isModified\0enableMessages"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KSudoku[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      29,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  159,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    3,  160,    2, 0x0a /* Public */,
       3,    2,  167,    2, 0x2a /* Public | MethodCloned */,
       7,    0,  172,    2, 0x0a /* Public */,
       8,    1,  173,    2, 0x0a /* Public */,
      11,    0,  176,    2, 0x0a /* Public */,
      12,    0,  177,    2, 0x0a /* Public */,
      13,    1,  178,    2, 0x08 /* Private */,
      13,    1,  181,    2, 0x08 /* Private */,
      16,    1,  184,    2, 0x08 /* Private */,
      18,    0,  187,    2, 0x08 /* Private */,
      19,    0,  188,    2, 0x08 /* Private */,
      20,    0,  189,    2, 0x08 /* Private */,
      21,    0,  190,    2, 0x08 /* Private */,
      22,    0,  191,    2, 0x08 /* Private */,
      23,    0,  192,    2, 0x08 /* Private */,
      24,    0,  193,    2, 0x08 /* Private */,
      25,    0,  194,    2, 0x08 /* Private */,
      26,    0,  195,    2, 0x08 /* Private */,
      27,    0,  196,    2, 0x08 /* Private */,
      28,    0,  197,    2, 0x08 /* Private */,
      29,    0,  198,    2, 0x08 /* Private */,
      30,    0,  199,    2, 0x08 /* Private */,
      31,    0,  200,    2, 0x08 /* Private */,
      32,    0,  201,    2, 0x08 /* Private */,
      33,    0,  202,    2, 0x08 /* Private */,
      34,    1,  203,    2, 0x08 /* Private */,
      36,    1,  206,    2, 0x08 /* Private */,
      38,    0,  209,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool, QMetaType::QTime, QMetaType::Bool,    4,    5,    6,
    QMetaType::Void, QMetaType::Bool, QMetaType::QTime,    4,    5,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   35,
    QMetaType::Void, QMetaType::Bool,   37,
    QMetaType::Void,

       0        // eod
};

void KSudoku::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KSudoku *_t = static_cast<KSudoku *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->settingsChanged(); break;
        case 1: _t->onCompleted((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const QTime(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 2: _t->onCompleted((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const QTime(*)>(_a[2]))); break;
        case 3: _t->showWelcomeScreen(); break;
        case 4: _t->startGame((*reinterpret_cast< const::ksudoku::Game(*)>(_a[1]))); break;
        case 5: _t->endCurrentGame(); break;
        case 6: { bool _r = _t->queryClose();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->difficultyChanged((*reinterpret_cast< KGameDifficulty::standardLevel(*)>(_a[1]))); break;
        case 8: _t->difficultyChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->symmetryChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->gameNew(); break;
        case 11: _t->gameOpen(); break;
        case 12: _t->gameSave(); break;
        case 13: _t->gameSaveAs(); break;
        case 14: _t->gamePrint(); break;
        case 15: _t->gameExport(); break;
        case 16: _t->undo(); break;
        case 17: _t->redo(); break;
        case 18: _t->push(); break;
        case 19: _t->pop(); break;
        case 20: _t->giveHint(); break;
        case 21: _t->autoSolve(); break;
        case 22: _t->dubPuzzle(); break;
        case 23: _t->genMultiple(); break;
        case 24: _t->optionsPreferences(); break;
        case 25: _t->updateSettings(); break;
        case 26: _t->changeCaption((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 27: _t->onModified((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 28: _t->enableMessages(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KSudoku::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KSudoku::settingsChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KSudoku::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_KSudoku.data,
      qt_meta_data_KSudoku,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KSudoku::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSudoku::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KSudoku.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KSudoku::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 29;
    }
    return _id;
}

// SIGNAL 0
void KSudoku::settingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
