/****************************************************************************
** Meta object code from reading C++ file 'ksudokugame.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/ksudoku-17.08.3/src/gui/ksudokugame.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ksudokugame.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ksudoku__GameIFace_t {
    QByteArrayData data[18];
    char stringdata0[175];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ksudoku__GameIFace_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ksudoku__GameIFace_t qt_meta_stringdata_ksudoku__GameIFace = {
    {
QT_MOC_LITERAL(0, 0, 18), // "ksudoku::GameIFace"
QT_MOC_LITERAL(1, 19, 8), // "modified"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 10), // "isModified"
QT_MOC_LITERAL(4, 40, 9), // "completed"
QT_MOC_LITERAL(5, 50, 9), // "isCorrect"
QT_MOC_LITERAL(6, 60, 8), // "required"
QT_MOC_LITERAL(7, 69, 8), // "withHelp"
QT_MOC_LITERAL(8, 78, 10), // "cellChange"
QT_MOC_LITERAL(9, 89, 5), // "index"
QT_MOC_LITERAL(10, 95, 10), // "fullChange"
QT_MOC_LITERAL(11, 106, 10), // "cageChange"
QT_MOC_LITERAL(12, 117, 7), // "cageNum"
QT_MOC_LITERAL(13, 125, 9), // "showLabel"
QT_MOC_LITERAL(14, 135, 4), // "undo"
QT_MOC_LITERAL(15, 140, 4), // "redo"
QT_MOC_LITERAL(16, 145, 13), // "addCheckpoint"
QT_MOC_LITERAL(17, 159, 15) // "undo2Checkpoint"

    },
    "ksudoku::GameIFace\0modified\0\0isModified\0"
    "completed\0isCorrect\0required\0withHelp\0"
    "cellChange\0index\0fullChange\0cageChange\0"
    "cageNum\0showLabel\0undo\0redo\0addCheckpoint\0"
    "undo2Checkpoint"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ksudoku__GameIFace[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x06 /* Public */,
       4,    3,   62,    2, 0x06 /* Public */,
       8,    1,   69,    2, 0x06 /* Public */,
      10,    0,   72,    2, 0x06 /* Public */,
      11,    2,   73,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    0,   78,    2, 0x0a /* Public */,
      15,    0,   79,    2, 0x0a /* Public */,
      16,    0,   80,    2, 0x0a /* Public */,
      17,    0,   81,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool, QMetaType::QTime, QMetaType::Bool,    5,    6,    7,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,   12,   13,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ksudoku::GameIFace::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GameIFace *_t = static_cast<GameIFace *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->modified((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->completed((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const QTime(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 2: _t->cellChange((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->fullChange(); break;
        case 4: _t->cageChange((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 5: _t->undo(); break;
        case 6: _t->redo(); break;
        case 7: _t->addCheckpoint(); break;
        case 8: _t->undo2Checkpoint(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (GameIFace::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameIFace::modified)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (GameIFace::*_t)(bool , const QTime & , bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameIFace::completed)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (GameIFace::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameIFace::cellChange)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (GameIFace::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameIFace::fullChange)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (GameIFace::*_t)(int , bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameIFace::cageChange)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject ksudoku::GameIFace::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_ksudoku__GameIFace.data,
      qt_meta_data_ksudoku__GameIFace,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ksudoku::GameIFace::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ksudoku::GameIFace::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ksudoku__GameIFace.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ksudoku::GameIFace::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void ksudoku::GameIFace::modified(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void ksudoku::GameIFace::completed(bool _t1, const QTime & _t2, bool _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void ksudoku::GameIFace::cellChange(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void ksudoku::GameIFace::fullChange()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ksudoku::GameIFace::cageChange(int _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
