/****************************************************************************
** Meta object code from reading C++ file 'welcomescreen.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/ksudoku-17.08.3/src/gui/welcomescreen.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'welcomescreen.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ksudoku__WelcomeScreen_t {
    QByteArrayData data[15];
    char stringdata0[206];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ksudoku__WelcomeScreen_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ksudoku__WelcomeScreen_t qt_meta_stringdata_ksudoku__WelcomeScreen = {
    {
QT_MOC_LITERAL(0, 0, 22), // "ksudoku::WelcomeScreen"
QT_MOC_LITERAL(1, 23, 14), // "newGameStarted"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 21), // "const::ksudoku::Game&"
QT_MOC_LITERAL(4, 61, 4), // "game"
QT_MOC_LITERAL(5, 66, 12), // "GameVariant*"
QT_MOC_LITERAL(6, 79, 7), // "variant"
QT_MOC_LITERAL(7, 87, 22), // "onCurrentVariantChange"
QT_MOC_LITERAL(8, 110, 13), // "getNewVariant"
QT_MOC_LITERAL(9, 124, 16), // "configureVariant"
QT_MOC_LITERAL(10, 141, 14), // "startEmptyGame"
QT_MOC_LITERAL(11, 156, 11), // "playVariant"
QT_MOC_LITERAL(12, 168, 14), // "generatePuzzle"
QT_MOC_LITERAL(13, 183, 18), // "setSelectedVariant"
QT_MOC_LITERAL(14, 202, 3) // "row"

    },
    "ksudoku::WelcomeScreen\0newGameStarted\0"
    "\0const::ksudoku::Game&\0game\0GameVariant*\0"
    "variant\0onCurrentVariantChange\0"
    "getNewVariant\0configureVariant\0"
    "startEmptyGame\0playVariant\0generatePuzzle\0"
    "setSelectedVariant\0row"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ksudoku__WelcomeScreen[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   54,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,   59,    2, 0x08 /* Private */,
       8,    0,   60,    2, 0x08 /* Private */,
       9,    0,   61,    2, 0x08 /* Private */,
      10,    0,   62,    2, 0x08 /* Private */,
      11,    0,   63,    2, 0x08 /* Private */,
      12,    0,   64,    2, 0x08 /* Private */,
      13,    1,   65,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   14,

       0        // eod
};

void ksudoku::WelcomeScreen::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        WelcomeScreen *_t = static_cast<WelcomeScreen *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->newGameStarted((*reinterpret_cast< const::ksudoku::Game(*)>(_a[1])),(*reinterpret_cast< GameVariant*(*)>(_a[2]))); break;
        case 1: _t->onCurrentVariantChange(); break;
        case 2: _t->getNewVariant(); break;
        case 3: _t->configureVariant(); break;
        case 4: _t->startEmptyGame(); break;
        case 5: _t->playVariant(); break;
        case 6: _t->generatePuzzle(); break;
        case 7: _t->setSelectedVariant((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (WelcomeScreen::*_t)(const ::ksudoku::Game & , GameVariant * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WelcomeScreen::newGameStarted)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject ksudoku::WelcomeScreen::staticMetaObject = {
    { &QFrame::staticMetaObject, qt_meta_stringdata_ksudoku__WelcomeScreen.data,
      qt_meta_data_ksudoku__WelcomeScreen,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ksudoku::WelcomeScreen::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ksudoku::WelcomeScreen::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ksudoku__WelcomeScreen.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int ksudoku::WelcomeScreen::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void ksudoku::WelcomeScreen::newGameStarted(const ::ksudoku::Game & _t1, GameVariant * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
