/****************************************************************************
** Meta object code from reading C++ file 'gameactions.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/ksudoku-17.08.3/src/gui/views/gameactions.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gameactions.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ksudoku__GameActions_t {
    QByteArrayData data[14];
    char stringdata0[118];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ksudoku__GameActions_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ksudoku__GameActions_t qt_meta_stringdata_ksudoku__GameActions = {
    {
QT_MOC_LITERAL(0, 0, 20), // "ksudoku::GameActions"
QT_MOC_LITERAL(1, 21, 11), // "selectValue"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 5), // "value"
QT_MOC_LITERAL(4, 40, 10), // "enterValue"
QT_MOC_LITERAL(5, 51, 9), // "markValue"
QT_MOC_LITERAL(6, 61, 4), // "move"
QT_MOC_LITERAL(7, 66, 2), // "dx"
QT_MOC_LITERAL(8, 69, 2), // "dy"
QT_MOC_LITERAL(9, 72, 10), // "clearValue"
QT_MOC_LITERAL(10, 83, 6), // "moveUp"
QT_MOC_LITERAL(11, 90, 8), // "moveDown"
QT_MOC_LITERAL(12, 99, 8), // "moveLeft"
QT_MOC_LITERAL(13, 108, 9) // "moveRight"

    },
    "ksudoku::GameActions\0selectValue\0\0"
    "value\0enterValue\0markValue\0move\0dx\0"
    "dy\0clearValue\0moveUp\0moveDown\0moveLeft\0"
    "moveRight"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ksudoku__GameActions[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   69,    2, 0x06 /* Public */,
       4,    1,   72,    2, 0x06 /* Public */,
       4,    0,   75,    2, 0x26 /* Public | MethodCloned */,
       5,    1,   76,    2, 0x06 /* Public */,
       5,    0,   79,    2, 0x26 /* Public | MethodCloned */,
       6,    2,   80,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    0,   85,    2, 0x08 /* Private */,
      10,    0,   86,    2, 0x08 /* Private */,
      11,    0,   87,    2, 0x08 /* Private */,
      12,    0,   88,    2, 0x08 /* Private */,
      13,    0,   89,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    7,    8,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ksudoku::GameActions::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GameActions *_t = static_cast<GameActions *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->selectValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->enterValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->enterValue(); break;
        case 3: _t->markValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->markValue(); break;
        case 5: _t->move((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 6: _t->clearValue(); break;
        case 7: _t->moveUp(); break;
        case 8: _t->moveDown(); break;
        case 9: _t->moveLeft(); break;
        case 10: _t->moveRight(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (GameActions::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameActions::selectValue)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (GameActions::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameActions::enterValue)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (GameActions::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameActions::markValue)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (GameActions::*_t)(int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameActions::move)) {
                *result = 5;
                return;
            }
        }
    }
}

const QMetaObject ksudoku::GameActions::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_ksudoku__GameActions.data,
      qt_meta_data_ksudoku__GameActions,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ksudoku::GameActions::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ksudoku::GameActions::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ksudoku__GameActions.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ksudoku::GameActions::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void ksudoku::GameActions::selectValue(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void ksudoku::GameActions::enterValue(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 3
void ksudoku::GameActions::markValue(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 5
void ksudoku::GameActions::move(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
