/****************************************************************************
** Meta object code from reading C++ file 'view2d.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/ksudoku-17.08.3/src/gui/views/view2d.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'view2d.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ksudoku__View2DScene_t {
    QByteArrayData data[17];
    char stringdata0[151];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ksudoku__View2DScene_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ksudoku__View2DScene_t qt_meta_stringdata_ksudoku__View2DScene = {
    {
QT_MOC_LITERAL(0, 0, 20), // "ksudoku::View2DScene"
QT_MOC_LITERAL(1, 21, 13), // "valueSelected"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 3), // "val"
QT_MOC_LITERAL(4, 40, 11), // "selectValue"
QT_MOC_LITERAL(5, 52, 10), // "enterValue"
QT_MOC_LITERAL(6, 63, 4), // "cell"
QT_MOC_LITERAL(7, 68, 9), // "markValue"
QT_MOC_LITERAL(8, 78, 3), // "set"
QT_MOC_LITERAL(9, 82, 13), // "flipMarkValue"
QT_MOC_LITERAL(10, 96, 10), // "moveCursor"
QT_MOC_LITERAL(11, 107, 2), // "dx"
QT_MOC_LITERAL(12, 110, 2), // "dy"
QT_MOC_LITERAL(13, 113, 6), // "update"
QT_MOC_LITERAL(14, 120, 10), // "updateCage"
QT_MOC_LITERAL(15, 131, 9), // "cageNumP1"
QT_MOC_LITERAL(16, 141, 9) // "drawLabel"

    },
    "ksudoku::View2DScene\0valueSelected\0\0"
    "val\0selectValue\0enterValue\0cell\0"
    "markValue\0set\0flipMarkValue\0moveCursor\0"
    "dx\0dy\0update\0updateCage\0cageNumP1\0"
    "drawLabel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ksudoku__View2DScene[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   79,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   82,    2, 0x0a /* Public */,
       5,    2,   85,    2, 0x0a /* Public */,
       5,    1,   90,    2, 0x2a /* Public | MethodCloned */,
       7,    3,   93,    2, 0x0a /* Public */,
       7,    2,  100,    2, 0x2a /* Public | MethodCloned */,
       7,    1,  105,    2, 0x2a /* Public | MethodCloned */,
       9,    2,  108,    2, 0x0a /* Public */,
       9,    1,  113,    2, 0x2a /* Public | MethodCloned */,
      10,    2,  116,    2, 0x0a /* Public */,
      13,    1,  121,    2, 0x0a /* Public */,
      13,    0,  124,    2, 0x2a /* Public | MethodCloned */,
      14,    2,  125,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    3,    6,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Bool,    3,    6,    8,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    3,    6,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    3,    6,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   11,   12,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,   15,   16,

       0        // eod
};

void ksudoku::View2DScene::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        View2DScene *_t = static_cast<View2DScene *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->valueSelected((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->selectValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->enterValue((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->enterValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->markValue((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 5: _t->markValue((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 6: _t->markValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->flipMarkValue((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 8: _t->flipMarkValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->moveCursor((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 10: _t->update((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->update(); break;
        case 12: _t->updateCage((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (View2DScene::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&View2DScene::valueSelected)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject ksudoku::View2DScene::staticMetaObject = {
    { &QGraphicsScene::staticMetaObject, qt_meta_stringdata_ksudoku__View2DScene.data,
      qt_meta_data_ksudoku__View2DScene,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ksudoku::View2DScene::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ksudoku::View2DScene::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ksudoku__View2DScene.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsScene::qt_metacast(_clname);
}

int ksudoku::View2DScene::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsScene::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void ksudoku::View2DScene::valueSelected(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_ksudoku__View2D_t {
    QByteArrayData data[6];
    char stringdata0[65];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ksudoku__View2D_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ksudoku__View2D_t qt_meta_stringdata_ksudoku__View2D = {
    {
QT_MOC_LITERAL(0, 0, 15), // "ksudoku::View2D"
QT_MOC_LITERAL(1, 16, 13), // "valueSelected"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 5), // "value"
QT_MOC_LITERAL(4, 37, 11), // "selectValue"
QT_MOC_LITERAL(5, 49, 15) // "settingsChanged"

    },
    "ksudoku::View2D\0valueSelected\0\0value\0"
    "selectValue\0settingsChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ksudoku__View2D[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   29,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   32,    2, 0x0a /* Public */,
       5,    0,   35,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,

       0        // eod
};

void ksudoku::View2D::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        View2D *_t = static_cast<View2D *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->valueSelected((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->selectValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->settingsChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (View2D::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&View2D::valueSelected)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject ksudoku::View2D::staticMetaObject = {
    { &QGraphicsView::staticMetaObject, qt_meta_stringdata_ksudoku__View2D.data,
      qt_meta_data_ksudoku__View2D,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ksudoku::View2D::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ksudoku::View2D::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ksudoku__View2D.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ViewInterface"))
        return static_cast< ViewInterface*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int ksudoku::View2D::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void ksudoku::View2D::valueSelected(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
